% File is a part of the package DiffEqLab.
% For documentation, see the file  diffeq.doc.
%
% Version 1.2 for Matlab 5
% Simo K. Kivel, July 1994, January 1997, January 1998, March 1998
%

Order=check(DeqSyst);

clear InitVals;

Lns=18+Order; Sp=1/Lns; LNumber=1;
Col1=0.1; Col2=0.2; Col3=0.35; Col4=0.55; Col5=0.7; Col6=0.87;
OKWidth=0.1; OKHeight=0.8*Sp; FldWidth=0.15;

TimDepAx=[-1 7 -3 3]; PhasPlAx=[-3 3 -3 3];

InitPt=0; TimInter=[-1 7];

ColorInd=1;

No='NNNNNNNNNN'; Yes='YYYYYYYYYY'; TDString=Yes(1:Order);
Zero='0000000000'; PPString=Zero(1:Order); PPString(1)='1'; PPString(2)='2'; 

% Phase plane window

PhasePl=figure('MenuBar','none','NumberTitle','off',...
   'Name','Phase plane',...
   'Units','centimeters','Position',PhasePlW,...
   'Color','black','DefaultAxesColor','black',...
   'DefaultAxesXColor','white','DefaultAxesYColor','white');

PPAxes=axes('Parent',PhasePl,'XLim',PhasPlAx(1:2),'YLim',PhasPlAx(3:4),...
   'XGrid','on','YGrid','on');

if Order==2, ppdirfld; end;

% Time dependence window

TimeDep=figure('MenuBar','none','NumberTitle','off',...
   'Name','Time dependence',...
   'Units','centimeters','Position',TimeDepW,...
   'Color','black','DefaultAxesColor','black',...
   'DefaultAxesXColor','white','DefaultAxesYColor','white');

TDAxes=axes('Parent',TimeDep,'XLim',TimDepAx(1:2),'YLim',TimDepAx(3:4),...
   'XGrid','on','YGrid','on');

% Control panel window

Panel2=figure('MenuBar','none','NumberTitle','off',...
   'Name','Control panel',...
   'Units','centimeters','Position',Panel2W,...
   'Color',[0.9,0.9,0.9],...
   'Resize','off');

axes('Units','normalized',...
   'Position',[0,0,1,1],...
   'Visible','off');

% The initial time

text('Units','normal',...
   'Position',[Col1,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','Initial values at  t = ');

TInit=uicontrol('Units','normal',...
   'Position',[0.55,(Lns-LNumber)*Sp,1.5*FldWidth,OKHeight],...
   'BackGroundColor','white',...
   'Style','edit',...
   'String',num2str(InitPt));

uicontrol('Units','normal',...
   'Position',[Col6,(Lns-LNumber)*Sp,OKWidth,OKHeight],...
   'Style','pushbutton',...
   'String','OK',...
   'CallBack',...
   ['Tmp=str2num(get(TInit,''String''));',...
    'if length(Tmp)==1 & TimInter(1)<=Tmp & Tmp<=TimInter(2),',...
    '  InitPt=Tmp;',...
    '  if Order==2,',...
    '    delete(get(PPAxes,''Children'')); ppdirfld;',...
    '  end;',...
    'else set(TInit,''String'',num2str(InitPt));end;']);

% Giving the initial values in the time dependence window by mouse

LNumber=LNumber+1;

text('Units','normal',...
   'Position',[Col2,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','in time dep. wind. by mouse');

uicontrol('Units','normal',...
   'Position',[Col6,(Lns-LNumber)*Sp,OKWidth,OKHeight],...
   'Style','pushbutton',...
   'String','OK',...
   'CallBack',...
   ['figure(TimeDep);',...
    'InitVals=[];',...
    'for K=1:Order,'...
    '  GraphInp=ginput(1);',...
    '  line(InitPt,GraphInp(2),''Color'',Color(ColorInd),'...
    '  ''Marker'',''o'',''Parent'',TDAxes);'...
    '  InitVals(K)=GraphInp(2);',...
    'end;',...
    'compsol2;',...
    'for K=1:Order,'...
    '  set(YInit(K),''String'',num2str(InitVals(K)));',...
    'end;']);

% Giving the initial values in the phase plane window by mouse

if Order==2,

LNumber=LNumber+1;

text('Units','normal',...
   'Position',[Col2,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','in phase pl. wind. by mouse');

uicontrol('Units','normal',...
   'Position',[Col6,(Lns-LNumber)*Sp,OKWidth,OKHeight],...
   'Style','pushbutton',...
   'String','OK',...
   'CallBack',...
   ['figure(PhasePl);',...
    'InitVals=ginput(1)'';',...
    'line(InitVals(1),InitVals(2),''Color'',Color(ColorInd),'...
    '''Marker'',''o'',''Parent'',PPAxes);',...
    'compsol2;',...
    'for K=1:Order,',...
    '  set(YInit(K),''String'',num2str(InitVals(K)));',...
    'end;']);

end;

% Giving the initial values numerically

LNumber=LNumber+1;

text('Units','normal',...
   'Position',[Col2,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','numerically');

for K=1:Order,

LNumber=LNumber+1;

text('Units','normal',...
   'Position',[0.3,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String',['y',num2str(K),' = ']);

YInit(K)=uicontrol('Units','normal',...
   'Position',[0.45,(Lns-LNumber)*Sp,1.5*FldWidth,OKHeight],...
   'BackGroundColor','white',...
   'Style','edit');

end;

uicontrol('Units','normal',...
   'Position',[Col6,(Lns-LNumber)*Sp,OKWidth,OKHeight],...
   'Style','pushbutton',...
   'String','OK',...
   'CallBack',...
   ['Ok=1;',...
    'for K=1:Order,',...
    '  Tmp=str2num(get(YInit(K),''String''));',...
    '  if length(Tmp)==1,',...
    '    InitVals(K)=Tmp;',...
    '  else',...
    '    Ok=0;',...
    '    if length(InitVals)>=K,',...
    '      set(YInit(K),''String'',num2str(InitVals(K)));',...
    '    else',...
    '      set(YInit(K),''String'','''');',...
    '    end;',...
    '  end;',...
    'end;',...
    'if Ok, compsol2; end;']);

% Giving the time interval

LNumber=LNumber+1;

text('Units','normal',...
   'Position',[Col1,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','Time interval');

LNumber=LNumber+1;

text('Units','normal',...
   'Position',[Col2,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','begin');

TBegin=uicontrol('Units','normal',...
   'Position',[Col3,(Lns-LNumber)*Sp,FldWidth,OKHeight],...
   'BackGroundColor','white',...
   'Style','edit',...
   'String',num2str(TimInter(1)));

text('Units','normal',...
   'Position',[Col4,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','end');

TEnd=uicontrol('Units','normal',...
   'Position',[Col5,(Lns-LNumber)*Sp,FldWidth,OKHeight],...
   'BackGroundColor','white',...
   'Style','edit',...
   'String',num2str(TimInter(2)));

uicontrol('Units','normal',...
   'Position',[Col6,(Lns-LNumber)*Sp,OKWidth,OKHeight],...
   'Style','pushbutton',...
   'String','OK',...
   'CallBack',...
   ['Tmp=str2num(get(TBegin,''String''));',...
    'if length(Tmp)==1 & Tmp<=InitPt,TimInter(1)=Tmp;',...
    'else set(TBegin,''String'',num2str(TimInter(1)));end;',...
    'Tmp=str2num(get(TEnd,''String''));',...
    'if length(Tmp)==1 & Tmp>=InitPt,TimInter(2)=Tmp;',...
    'else set(TEnd,''String'',num2str(TimInter(2)));end;']);

% Time dependence area / clear

LNumber=LNumber+1;

text('Units','normal',...
   'Position',[Col1,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','Time dependence area / clear');

LNumber=LNumber+1;

text('Units','normal',...
   'Position',[Col2,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','tlow');

TLow=uicontrol('Units','normal',...
   'Position',[Col3,(Lns-LNumber)*Sp,FldWidth,OKHeight],...
   'BackGroundColor','white',...
   'Style','edit',...
   'String',num2str(TimDepAx(1)));

text('Units','normal',...
   'Position',[Col4,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','thigh');

THigh=uicontrol('Units','normal',...
   'Position',[Col5,(Lns-LNumber)*Sp,FldWidth,OKHeight],...
   'BackGroundColor','white',...
   'Style','edit',...
   'String',num2str(TimDepAx(2)));

LNumber=LNumber+1;

text('Units','normal',...
   'Position',[Col2,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','ylow');

YLow=uicontrol('Units','normal',...
   'Position',[Col3,(Lns-LNumber)*Sp,FldWidth,OKHeight],...
   'BackGroundColor','white',...
   'Style','edit',...
   'String',num2str(TimDepAx(3)));

text('Units','normal',...
   'Position',[Col4,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','yhigh');

YHigh=uicontrol('Units','normal',...
   'Position',[Col5,(Lns-LNumber)*Sp,FldWidth,OKHeight],...
   'BackGroundColor','white',...
   'Style','edit',...
   'String',num2str(TimDepAx(4)));

uicontrol('Units','normal',...
   'Position',[Col6,(Lns-LNumber)*Sp,OKWidth,OKHeight],...
   'Style','pushbutton',...
   'String','OK',...
   'CallBack',...
   ['TmpLow=str2num(get(TLow,''String''));',...
    'TmpHigh=str2num(get(THigh,''String''));',...
    'if length(TmpLow)==1 & length(TmpHigh)==1 & TmpLow<TmpHigh,',...
    '  TimDepAx(1)=TmpLow; TimDepAx(2)=TmpHigh;',...
    'else set(TLow,''String'',num2str(TimDepAx(1)));',...
    '  set(THigh,''String'',num2str(TimDepAx(2)));end;',...
    'TmpLow=str2num(get(YLow,''String''));',...
    'TmpHigh=str2num(get(YHigh,''String''));',...
    'if length(TmpLow)==1 & length(TmpHigh)==1 & TmpLow<TmpHigh,',...
    '  TimDepAx(3)=TmpLow; TimDepAx(4)=TmpHigh;',...
    'else set(YLow,''String'',num2str(TimDepAx(3)));',...
    '  set(YHigh,''String'',num2str(TimDepAx(4)));end;',...
    'delete(get(TimeDep,''Children''));',...
    'TDAxes=axes(''Parent'',TimeDep,''XLim'',TimDepAx(1:2),'...
    '''YLim'',TimDepAx(3:4),''XGrid'',''on'',''YGrid'',''on'');']);

% Phase plane area / clear

LNumber=LNumber+1;

text('Units','normal',...
   'Position',[Col1,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','Phase plane area / clear');

LNumber=LNumber+1;

text('Units','normal',...
   'Position',[Col2,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','hlow');

HLow=uicontrol('Units','normal',...
   'Position',[Col3,(Lns-LNumber)*Sp,FldWidth,OKHeight],...
   'BackGroundColor','white',...
   'Style','edit',...
   'String',num2str(PhasPlAx(1)));

text('Units','normal',...
   'Position',[Col4,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','hhigh');

HHigh=uicontrol('Units','normal',...
   'Position',[Col5,(Lns-LNumber)*Sp,FldWidth,OKHeight],...
   'BackGroundColor','white',...
   'Style','edit',...
   'String',num2str(PhasPlAx(2)));

LNumber=LNumber+1;

text('Units','normal',...
   'Position',[Col2,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','vlow');

VLow=uicontrol('Units','normal',...
   'Position',[Col3,(Lns-LNumber)*Sp,FldWidth,OKHeight],...
   'BackGroundColor','white',...
   'Style','edit',...
   'String',num2str(PhasPlAx(3)));

text('Units','normal',...
   'Position',[Col4,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','vhigh');

VHigh=uicontrol('Units','normal',...
   'Position',[Col5,(Lns-LNumber)*Sp,FldWidth,OKHeight],...
   'BackGroundColor','white',...
   'Style','edit',...
   'String',num2str(PhasPlAx(4)));

uicontrol('Units','normal',...
   'Position',[Col6,(Lns-LNumber)*Sp,OKWidth,OKHeight],...
   'Style','pushbutton',...
   'String','OK',...
   'CallBack',...
   ['TmpLow=str2num(get(HLow,''String''));',...
    'TmpHigh=str2num(get(HHigh,''String''));',...
    'if length(TmpLow)==1 & length(TmpHigh)==1 & TmpLow<TmpHigh,',...
    '  PhasPlAx(1)=TmpLow; PhasPlAx(2)=TmpHigh;',...
    'else set(HLow,''String'',num2str(PhasPlAx(1)));',...
    '  set(HHigh,''String'',num2str(PhasPlAx(2)));end;',...
    'TmpLow=str2num(get(VLow,''String''));',...
    'TmpHigh=str2num(get(VHigh,''String''));',...
    'if length(TmpLow)==1 & length(TmpHigh)==1 & TmpLow<TmpHigh,',...
    '  PhasPlAx(3)=TmpLow; PhasPlAx(4)=TmpHigh;',...
    'else set(VLow,''String'',num2str(PhasPlAx(3)));',...
    '  set(VHigh,''String'',num2str(PhasPlAx(4)));end;',...
    'delete(get(PhasePl,''Children''));',...
    'PPAxes=axes(''Parent'',PhasePl,''XLim'',PhasPlAx(1:2),'...
    '''YLim'',PhasPlAx(3:4),''XGrid'',''on'',''YGrid'',''on'');'...
    'if Order==2, ppdirfld; end;']);

% Functions in the time dependence window

LNumber=LNumber+1;

text('Units','normal',...
   'Position',[Col1,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','Functions in time dep. window');

LNumber=LNumber+1;

TimDepFs=uicontrol('Units','normal',...
   'Position',[Col3,(Lns-LNumber)*Sp,3.3*FldWidth,OKHeight],...
   'BackGroundColor','white',...
   'Style','edit',...
   'String',TDString);

uicontrol('Units','normal',...
   'Position',[Col6,(Lns-LNumber)*Sp,OKWidth,OKHeight],...
   'Style','pushbutton',...
   'String','OK',...
   'CallBack',...
   ['Tmp=get(TimDepFs,''String'');',...
    'if length(Tmp)==Order &',...
    '  length(find(Tmp==''Y''))+length(find(Tmp==''N''))==Order,',...
    '  TDString=Tmp;',...
    'else set(TimDepFs,''String'',TDString);end;']);

% Functions in the phase plane window

if Order~=2

LNumber=LNumber+1;

text('Units','normal',...
   'Position',[Col1,(Lns-LNumber)*Sp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','Functions in phase pl. window');

LNumber=LNumber+1;

PhasPlFs=uicontrol('Units','normal',...
   'Position',[Col3,(Lns-LNumber)*Sp,3.3*FldWidth,OKHeight],...
   'BackGroundColor','white',...
   'Style','edit',...
   'String',PPString);

uicontrol('Units','normal',...
   'Position',[Col6,(Lns-LNumber)*Sp,OKWidth,OKHeight],...
   'Style','pushbutton',...
   'String','OK',...
   'CallBack',...
   ['Tmp=get(PhasPlFs,''String'');',...
    'if length(Tmp)==Order & length(find(Tmp==''1''))==1 &',...
    '  length(find(Tmp==''2''))==1 & length(find(Tmp==''0''))==Order-2,',...
    '  PPString=Tmp;',...
    'else set(PhasPlFs,''String'',PPString);end;']);

end;

% Help

LNumber=LNumber+2.5;

uicontrol('Units','normal',...
   'Position',[0.15,(Lns-LNumber)*Sp,0.3,0.06],...
   'Style','pushbutton',...
   'String','HELP',...
   'CallBack','clc;help2');

% Close

uicontrol('Units','normal',...
   'Position',[0.55,(Lns-LNumber)*Sp,0.3,0.06],...
   'Style','pushbutton',...
   'String','CLOSE',...
   'CallBack',...
   ['clear InitVals;',...
    'Childs=get(0,''Children'');',...
    'if any(Childs==TimeDep), close(TimeDep);end;',...
    'if any(Childs==PhasePl), close(PhasePl);end;',...
    'if any(Childs==Panel2), close(Panel2);end;']);
