% File is a part of the package DiffEqLab.
% For documentation, see the file  diffeq.doc.
%
% Version 1.2 for Matlab 5
% Simo K. Kivel, July 1994, January 1997, January 1998, March 1998
%

function [tout, yout] = ode(FunFcn, t0, tfinal, y0)

% Integrates a system of ordinary differential equations using
% 2nd and 3rd order Runge-Kutta formulas. Both forward and
% backward integration are possible.
% 
% Modified from the file ode23.m .

%  C.B. Moler, 3-25-87.
%  Copyright (c) 1987 by the MathWorks, Inc.
%  All rights reserved.
%  Modifications by Simo K. Kivel, 19.1.1992.

% Initialization
pow = 1/3;
tol = 0.001;

t = t0;
hmax = abs(tfinal - t)/5;
hmin = abs(tfinal - t)/20000;
h = (tfinal - t)/100;
y = y0(:);
tout = t;
yout = y.';
tau = tol * max(norm(y, 'inf'), 1);

% The main loop
   while (abs(t - tfinal) > 0) & (abs(h) >= hmin)
      if (h > 0 & t + h > tfinal) | (h < 0 & t + h < tfinal)
         h = tfinal - t;
      end;

      % Compute the slopes
      s1 = feval(FunFcn, t, y);
      s2 = feval(FunFcn, t+h, y+h*s1);
      s3 = feval(FunFcn, t+h/2, y+h*(s1+s2)/4);

      % Estimate the error and the acceptable error
      delta = norm(h*(s1 - 2*s3 + s2)/3,'inf');
      tau = tol*max(norm(y,'inf'),1.0);

     % Update the solution only if the error is acceptable
      if delta <= tau
         t = t + h;
         y = y + h*(s1 + 4*s3 + s2)/6;
         tout = [tout; t];
         yout = [yout; y.'];
      end

      % Update the step size
      if delta ~= 0.0
         h = sign(h)*min(hmax, 0.9*abs(h)*(tau/delta)^pow);
      end
   end;

   if (h > 0 & t < tfinal) | (h < 0 & t > tfinal)
      disp(['Singularity likely at ', num2str(t)])
   end
