% File is a part of the package DiffEqLab.
% For documentation, see the file  diffeq.doc.
%
% Version 1.2 for Matlab 5
% Simo K. Kivel, July 1994, January 1997, January 1998, March 1998
%

StartLns=6; StartSp=1/StartLns;

EqOrSys=[1,0];

% Starting box

Start=figure('MenuBar','none',...
   'NumberTitle','off',...
   'Name','DiffEqLab',...
   'Units','centimeters',...
   'Position',StartW,...
   'Color',[0.9,0.9,0.9],...
   'Resize','off');

axes('Units','normalized',...
   'Position',[0,0,1,1],...
   'Visible','off');

% Checking the case: single equation or system of equations

text('Units','normal',...
   'Position',[0.1,(StartLns-1)*StartSp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','Check one:    Single equation');

Eq=uicontrol('Units','normal',...
   'Position',[0.43,(StartLns-1)*StartSp,0.025,0.06],...
   'BackGroundColor','white',...
   'Style','checkbox',...
   'Value',EqOrSys(1),...
   'CallBack',...
   ['EqOrSys=~EqOrSys;',...
    'set(Eq,''Value'',EqOrSys(1));',...
    'set(Sys,''Value'',EqOrSys(2));',...
    'set(SysName,''String'','''');']);

text('Units','normal',...
   'Position',[0.5,(StartLns-1)*StartSp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','or system');

Sys=uicontrol('Units','normal',...
   'Position',[0.62,(StartLns-1)*StartSp,0.025,0.06],...
   'BackGroundColor','white',...
   'Style','checkbox',...
   'CallBack',...
   ['EqOrSys=~EqOrSys;',...
    'set(Eq,''Value'',EqOrSys(1));',...
    'set(Sys,''Value'',EqOrSys(2));',...
    'set(SysName,''String'','''');']);

% Selecting the system by name

text('Units','normal',...
   'Position',[0.1,(StartLns-2)*StartSp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','Name of the system (if you know):');

SysName=uicontrol('Units','normal',...
   'Position',[0.5,(StartLns-2)*StartSp,0.15,0.07],...
   'BackGroundColor','white',...
   'Style','edit');

uicontrol('Units','normal',...
   'Position',[0.67,(StartLns-2)*StartSp,0.08,0.1],...
   'Style','pushbutton',...
   'String','OK',...
   'CallBack',...
   ['DeqFile=[get(SysName,''String''),''.m''];',...
    'showsyst']);

% Selecting the system from the library

text('Units','normal',...
   'Position',[0.1,(StartLns-3)*StartSp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','Directory of the library:');

uicontrol('Units','normal',...
   'Position',[0.5,(StartLns-3)*StartSp,0.1,0.1],...
   'Style','pushbutton',...
   'String','Show',...
   'CallBack',...
   ['if get(Eq,''Value''), DeqFile=feval(GetFile,Libr1);end;',...
    'if get(Sys,''Value''), DeqFile=feval(GetFile,Libr2);end;',...
    'if ~strcmp(GetFile,''gfother''), showsyst; end;',...
    'set(SysName,''String'',DeqSyst);']);

% Selecting the system from the working directory

text('Units','normal',...
   'Position',[0.1,(StartLns-4)*StartSp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String','Working directory:');

uicontrol('Units','normal',...
   'Position',[0.5,(StartLns-4)*StartSp,0.1,0.1],...
   'Style','pushbutton',...
   'String','Show',...
   'CallBack',...
   ['DeqFile=feval(GetFile,pwd);',...
    'if ~strcmp(GetFile,''gfother''), showsyst; end;',...
    'set(SysName,''String'',DeqSyst);']);

% Start: OK!

uicontrol('Units','normal',...
   'Position',[0.85,(StartLns-2)*StartSp,0.1,0.2],...
   'Style','pushbutton',...
   'String','GO!',...
   'CallBack',...
   ['if exist(''DeqSyst'')==1, if exist([DeqSyst,''.m''])==2,'...
    'if get(Eq,''Value''), go1; else go2; end;'...
    'end;end']);

% Exit

uicontrol('Units','normal',...
   'Position',[0.85,(StartLns-4)*StartSp,0.1,0.2],...
   'Style','pushbutton',...
   'String','EXIT',...
   'CallBack',...
   ['path(OldPath);',...
    'close(get(0,''Children''));',...
    'clear']);

% Copyright

text('Units','normal',...
   'Position',[0.1,(StartLns-5)*StartSp],...
   'VerticalAlignment','bottom',...
   'Color','black',...
   'FontSize',FntSz,...
   'String',...
   'Copyright    Simo K. Kivel, Helsinki University of Technology, 1994');

% About

uicontrol('Units','normal',...
   'Position',[0.85,(StartLns-5)*StartSp,0.1,0.1],...
   'Style','pushbutton',...
   'String','About',...
   'CallBack','clc;about');
